SWDEV-549309 - Ensure that the kernel is issued to a stream that is ass… (#552)

* SWDEV-549309 - Ensure that the kernel is issued to a stream that is associated to the current device

* SWDEV-549309 - Ensure that the kernel is issued to a stream that is associated to the current device in atomic tests

* SWDEV-549309 - Added fix for Unit_hipMallocFromPoolAsync_Multidevice_Concurrent test

* SWDEV-549309 - Added fix for Unit_hipMemcpyPeerAsync_Positive_Default

* SWDEV-549309 - Added fix for Unit_hipStreamAttachMemAsync_Positive_AttachGlobal and Unit_hipGetProcAddress_GraphAPIs_AddMemsetMemcpyNodes

[ROCm/hip-tests commit: d21a95cea8]
This commit is contained in:
Assiouras, Ioannis
2025-08-14 07:20:56 +01:00
کامیت شده توسط GitHub
والد 17d12dff14
کامیت 5283a114b2
15فایلهای تغییر یافته به همراه38 افزوده شده و 21 حذف شده
@@ -51,9 +51,6 @@ TEST_CASE("Unit_hipMemcpyPeerAsync_Positive_Default") {
HipTest::HIP_SKIP_TEST("Skipping because devices < 2");
return;
}
const auto stream_type = GENERATE(Streams::nullstream, Streams::perThread, Streams::created);
const StreamGuard stream_guard(stream_type);
const hipStream_t stream = stream_guard.stream();
const auto allocation_size = GENERATE(kPageSize / 2, kPageSize, kPageSize * 2);
@@ -64,6 +61,11 @@ TEST_CASE("Unit_hipMemcpyPeerAsync_Positive_Default") {
INFO("Src device: " << src_device << ", Dst device: " << dst_device);
HIP_CHECK(hipSetDevice(src_device));
const auto stream_type = GENERATE(Streams::nullstream, Streams::perThread, Streams::created);
const StreamGuard stream_guard(stream_type);
const hipStream_t stream = stream_guard.stream();
HIP_CHECK(hipDeviceCanAccessPeer(&can_access_peer, src_device, dst_device));
if (can_access_peer) {
HIP_CHECK(hipDeviceEnablePeerAccess(dst_device, 0));